pub use fuel_tx::ContractId;
pub use fuel_tx::{Transaction, TxId};
use fuel_types::Word;

pub type GasPrice = Word;
